@@ -38,7 +38,6 @@
 #include <ctype.h>
 #include <regex.h>
 #include <limits.h>
-#include <math.h>
 
 
 #include "NumberFormatException.h"
@@ -55,16 +54,6 @@
  */
 
 
-/* ----------------------------------------------------------- Definitions */
-
-
-static double epsilon = 1e-6;
-
-static boolean_t _isInt(double x) {
-        return fabs(x - round(x)) < epsilon;
-}
-
-
 /* -------------------------------------------------------- Public Methods */
 
 
@@ -445,52 +434,6 @@ int Str_compareConstantTime(const void *x, const void *y) {
 }
 
 
-char *Str_bytes2str(double bytes, char s[10]) {
-        assert(s);
-        static const char *kNotation[] = {"B", "kB", "MB", "GB", "TB", "PB", "EB", "ZB", NULL};
-        *s = 0;
-        char *sign = (bytes < 0) ? "-" : "";
-        bytes = fabs(bytes);
-        assert(bytes < 1e+24);
-        for (int i = 0; kNotation[i]; i++) {
-                if (bytes >= 1024) {
-                        bytes /= 1024;
-                } else {
-                        snprintf(s, 10, _isInt(bytes) ? "%s%.0lf %s" : "%s%.1lf %s", sign, bytes, kNotation[i]);
-                        break;
-                }
-        }
-        return s;
-}
-
-
-char *Str_time2str(double milli, char s[11]) {
-        assert(s);
-        struct conversion {
-                double base;
-                char *suffix;
-        } conversion[] = {
-                {1000, "ms"}, // millisecond
-                {60,   "s"},  // second
-                {60,   "m"},  // minute
-                {24,   "h"},  // hour
-                {365,  "d"},  // day
-                {999,  "y"}   // year
-        };
-        *s = 0;
-        char *sign = (milli < 0) ? "-" : "";
-        milli = fabs(milli);
-        assert(milli < 3.14e+12); // -99.569 y
-        for (int i = 0; i < (sizeof(conversion) / sizeof(conversion[0])); i++) {
-                if (milli >= conversion[i].base) {
-                        milli /= conversion[i].base;
-                } else {
-                        snprintf(s, 11, _isInt(milli) ? "%s%.0lf %s" : "%s%.3lf %s", sign, milli, conversion[i].suffix);
-                        break;
-                }
-        }
-        return s;
-}
 
 
 
