@@ -61,6 +61,7 @@
 #include "system/Time.h"
 
 // libmonit
+#include "util/Fmt.h"
 #include "exceptions/AssertException.h"
 
 
@@ -143,7 +144,7 @@ static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, int6
                                 *timeout -= RETRY_INTERVAL;
                         } while ((status = Process_exitStatus(P)) < 0 && *timeout > 0 && ! (Run.flags & Run_Stopped));
                         if (*timeout <= 0)
-                                snprintf(msg, msglen, "Program '%s' timed out after %s", Util_commandDescription(c, (char[STRLEN]){}), Str_time2str(_timeoutMilli, (char[10]){}));
+                                snprintf(msg, msglen, "Program '%s' timed out after %s", Util_commandDescription(c, (char[STRLEN]){}), Fmt_time2str(_timeoutMilli, (char[11]){}));
                         int n, total = 0;
                         char buf[STRLEN];
                         do {
@@ -241,7 +242,7 @@ static boolean_t _doStart(Service_T s) {
                 if (s->start) {
                         if (s->type != Service_Process || ! ProcessTree_findProcess(s)) {
                                 LogInfo("'%s' start: '%s'\n", s->name, Util_commandDescription(s->start, (char[STRLEN]){}));
-                                char msg[STRLEN];
+                                char msg[1024];
                                 int64_t timeout = s->start->timeout * USEC_PER_MSEC;
                                 int status = _commandExecute(s, s->start, msg, sizeof(msg), &timeout);
                                 if (status < 0 || (s->type == Service_Process && _waitProcessStart(s, &timeout) != Process_Started)) {
@@ -291,7 +292,7 @@ static boolean_t _doStop(Service_T s, boolean_t unmonitor) {
         if (s->stop) {
                 if (s->monitor != Monitor_Not) {
                         int exitStatus;
-                        char msg[STRLEN];
+                        char msg[1024];
                         int64_t timeout = s->stop->timeout * USEC_PER_MSEC;
                         if (s->type == Service_Process) {
                                 int pid = ProcessTree_findProcess(s);
@@ -329,7 +330,7 @@ static boolean_t _doRestart(Service_T s) {
         if (s->restart) {
                 LogInfo("'%s' restart: '%s'\n", s->name, Util_commandDescription(s->restart, (char[STRLEN]){}));
                 Util_resetInfo(s);
-                char msg[STRLEN];
+                char msg[1024];
                 int64_t timeout = s->restart->timeout * USEC_PER_MSEC;
                 int status = _commandExecute(s, s->restart, msg, sizeof(msg), &timeout);
                 if (status < 0 || (s->type == Service_Process && _waitProcessStart(s, &timeout) != Process_Started)) {
