@@ -297,6 +297,7 @@ static void _gc_service(Service_T *s) {
                         break;
         }
         FREE((*s)->name);
+        FREE((*s)->name_escaped);
         FREE((*s)->path);
         (*s)->next = NULL;
         FREE(*s);
@@ -396,6 +397,9 @@ static void _gcportlist(Port_T *p) {
         } else if ((*p)->protocol->check == check_generic) {
                 if ((*p)->parameters.generic.sendexpect)
                         _gcgeneric(&(*p)->parameters.generic.sendexpect);
+        } else if ((*p)->protocol->check == check_mqtt) {
+                FREE((*p)->parameters.mqtt.username);
+                FREE((*p)->parameters.mqtt.password);
         } else if ((*p)->protocol->check == check_mysql) {
                 FREE((*p)->parameters.mysql.username);
                 FREE((*p)->parameters.mysql.password);
@@ -631,6 +635,7 @@ static void _gcpdl(Dependant_T *d) {
         if ((*d)->next)
                 _gcpdl(&(*d)->next);
         FREE((*d)->dependant);
+        FREE((*d)->dependant_escaped);
         FREE(*d);
 }
 
