@@ -106,6 +106,6 @@ void escapeHTML(StringBuffer_T sb, const char *s);
 void send_error(HttpRequest, HttpResponse, int status, const char *message, ...) __attribute__((format (printf, 4, 5)));
 const char *get_parameter(HttpRequest req, const char *parameter_name);
 void set_header(HttpResponse res, const char *name, const char *value, ...) __attribute__((format (printf, 3, 4)));
-void Processor_setHttpPostLimit();
+void Processor_setHttpPostLimit(void);
 
 #endif
