@@ -199,8 +199,8 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
                                 LogError("proc_pidinfo for pid %d -- invalid result size\n", pt[i].pid);
                         } else {
                                 pt[i].memory.usage = (uint64_t)tinfo.pti_resident_size;
-                                pt[i].cpu.time     = (double)(tinfo.pti_total_user + tinfo.pti_total_system) / 100000000.; // The time is in nanoseconds, we store it as 1/10s
-                                pt[i].threads      = tinfo.pti_threadnum;
+                                pt[i].cpu.time = (double)(tinfo.pti_total_user + tinfo.pti_total_system) / 100000000.; // The time is in nanoseconds, we store it as 1/10s
+                                pt[i].threads.self = tinfo.pti_threadnum;
                         }
 #ifdef rusage_info_current
                         // Disk IO
