@@ -32,6 +32,7 @@
 
 // libmonit
 #include "exceptions/IOException.h"
+#include "exceptions/ProtocolException.h"
 
 /**
  *  Send PING and check for PONG.
@@ -51,6 +52,6 @@ void check_clamav(Socket_T socket) {
                 THROW(IOException, "CLAMAV: PONG read error -- %s", STRERROR);
         Str_chomp(buf);
         if (strncasecmp(buf, "PONG", 4) != 0)
-                THROW(IOException, "CLAMAV: invalid PONG response -- %s", buf);
+                THROW(ProtocolException, "CLAMAV: invalid PONG response -- %s", buf);
 }
 
