@@ -1117,7 +1117,7 @@ void Util_printService(Service_T s) {
                 }
 #endif
                 StringBuffer_clear(buf);
-                printf(" %-20s = %s\n", "Port", StringBuffer_toString(Util_printRule(buf, o->action, StringBuffer_toString(buf2))));
+                printf(" %-20s = %s\n", "Port", StringBuffer_toString(Util_printRule(buf, o->action, "%s", StringBuffer_toString(buf2))));
                 StringBuffer_free(&buf2);
         }
 
@@ -1126,7 +1126,7 @@ void Util_printService(Service_T s) {
                 if (o->retry > 1)
                         printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed %s type %s protocol %s with timeout %s and retry %d times", o->target.unix.pathname, Util_portTypeDescription(o), o->protocol->name, Fmt_time2str(o->timeout, (char[11]){}), o->retry)));
                 else
-                        printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed %s type %s protocol %s with timeout %s", o->target.unix.pathname, Util_portTypeDescription(o), o->protocol->name, Fmt_time2str(o->timeout, (char[11]){}), o->retry)));
+                        printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed %s type %s protocol %s with timeout %s", o->target.unix.pathname, Util_portTypeDescription(o), o->protocol->name, Fmt_time2str(o->timeout, (char[11]){}))));
         }
 
         for (Timestamp_T o = s->timestamplist; o; o = o->next) {
@@ -1301,15 +1301,27 @@ void Util_printService(Service_T s) {
                                 break;
 
                         case Resource_LoadAverage1m:
-                                printf(" %-20s = ", "Load avg. (1min)");
+                                printf(" %-20s = ", "Load avg (1m)");
                                 break;
 
                         case Resource_LoadAverage5m:
-                                printf(" %-20s = ", "Load avg. (5min)");
+                                printf(" %-20s = ", "Load avg (5m)");
                                 break;
 
                         case Resource_LoadAverage15m:
-                                printf(" %-20s = ", "Load avg. (15min)");
+                                printf(" %-20s = ", "Load avg (15m)");
+                                break;
+
+                        case Resource_LoadAveragePerCore1m:
+                                printf(" %-20s = ", "Load avg/core (1m)");
+                                break;
+
+                        case Resource_LoadAveragePerCore5m:
+                                printf(" %-20s = ", "Load avg/core (5m)");
+                                break;
+
+                        case Resource_LoadAveragePerCore15m:
+                                printf(" %-20s = ", "Load avg/core (15m)");
                                 break;
 
                         case Resource_Threads:
@@ -1368,6 +1380,9 @@ void Util_printService(Service_T s) {
                         case Resource_LoadAverage1m:
                         case Resource_LoadAverage5m:
                         case Resource_LoadAverage15m:
+                        case Resource_LoadAveragePerCore1m:
+                        case Resource_LoadAveragePerCore5m:
+                        case Resource_LoadAveragePerCore15m:
                                 printf("%s", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %.1f", operatornames[o->operator], o->limit)));
                                 break;
 
